#include <Arduino.h>
#include <Preferences.h>
#include <esp_now.h>
#include <WiFi.h>

#define PIR_SENSOR_PIN 27

// REPLACE WITH YOUR RECEIVER MAC Address
//uint8_t broadcastAddress[] = {0x8C, 0x4B, 0x14, 0x9F, 0x03, 0xFC};
uint8_t broadcastAddress[] = {0x8C, 0x4B, 0x14, 0x9E, 0xF4, 0x24}; 

// Structure example to send data
// Must match the receiver structure
typedef struct struct_message {
int id;
int x;
int y;
} struct_message;

// Create a struct_message called myData
struct_message myData;

// callback when data is sent
void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
Serial.print("\r\nLast Packet Send Status:\t");
Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Delivery Success" : "Delivery Fail");
}

void setup() {
Serial.begin(115200);
pinMode(PIR_SENSOR_PIN, INPUT);



// Set device as a Wi-Fi Station
WiFi.mode(WIFI_STA);



// Init ESP-NOW
if (esp_now_init() != ESP_OK) {
Serial.println("Error initializing ESP-NOW");
return;
}

// Once ESPNow is successfully Init, we will register for Send CB to
// get the status of Trasnmitted packet
esp_now_register_send_cb(OnDataSent);

// Register peer
esp_now_peer_info_t peerInfo ={};
memcpy(peerInfo.peer_addr, broadcastAddress, 6);
peerInfo.channel = 0;
peerInfo.encrypt = false;

// Add peer
if (esp_now_add_peer(&peerInfo) != ESP_OK){
Serial.println("Failed to add peer");
return;
}
}

void loop() {
// Read PIR sensor value
int sensorValue = digitalRead(PIR_SENSOR_PIN);


// Set values to send
myData.id = 2;
myData.x = sensorValue;
myData.y = 23; //random identifier for sensor

// Send message via ESP-NOW
esp_err_t result = esp_now_send(broadcastAddress, (uint8_t *) &myData, sizeof(myData));

// The following is only used for testing, to check data in Serial Monitor
Serial.print("PIR Sensor Value: ");
Serial.println(myData.x);

if (result == ESP_OK) {
Serial.println("Sent with success");
}
else {
Serial.println("Error sending the data");
}
delay(2000); // Send data every two seconds
}